@@ -647,12 +647,8 @@ class MadTPG_Net(MadTPGBase):
 		self._commandno = 0
 		self._commands = {}
 		self._host = get_network_addr()
-		try:
-			hostname = get_valid_host()[0]
-		except socket.error:
-			hostname = self._host
 		self._incoming = {}
-		self._ips = [i[4][0] for i in socket.getaddrinfo(hostname, None)]
+		self._ips = [i[4][0] for i in socket.getaddrinfo(self._host, None)]
 		self._pid = 0
 		self._reset()
 		self._server_sockets = {}
@@ -1178,6 +1174,12 @@ class MadTPG_Net(MadTPGBase):
 			self._remove_client(addr)
 		self._incoming[addr].append((commandno, command, params, component))
 
+	def get_black_and_white_level(self):
+		# XXX: madHcNetXX.dll exports madVR_GetBlackAndWhiteLevel,
+		# but the equivalent madVR network protocol command is
+		# GetBlackWhiteLevel (without the "And")!
+		return MadTPG_Net_Sender(self, self._client_socket, "GetBlackWhiteLevel")()
+
 	def get_version(self):
 		""" Return madVR version """
 		try:
@@ -1341,15 +1343,18 @@ class MadTPG_Net(MadTPGBase):
 					params[param] = tuple(values)
 		elif command == "reply":
 			commandno = record["commandNo"]
-			repliedcomamnd = self._commands.get(commandno)
-			if repliedcomamnd:
+			repliedcommand = self._commands.get(commandno)
+			if repliedcommand:
 				self._commands.pop(commandno)
-				if repliedcomamnd == "GetBlackAndWhiteLevel":
+				# XXX: madHcNetXX.dll exports madVR_GetBlackAndWhiteLevel,
+				# but the equivalent madVR network protocol command is
+				# GetBlackWhiteLevel (without the "And")!
+				if repliedcommand == "GetBlackWhiteLevel":
 					if len(params) == 8:
 						params = struct.unpack("<ii", params)
 					else:
 						params = False
-				elif repliedcomamnd == "GetDeviceGammaRamp":
+				elif repliedcommand == "GetDeviceGammaRamp":
 					# Convert to ushort_Array_256_Array_3
 					ramp = ((ctypes.c_ushort * 256) * 3)()
 					if len(params) == 1536:
@@ -1360,12 +1365,12 @@ class MadTPG_Net(MadTPGBase):
 						params = ramp
 					else:
 						params = False
-				elif repliedcomamnd == "GetPatternConfig":
+				elif repliedcommand == "GetPatternConfig":
 					if len(params) == 16:
 						params = struct.unpack("<iiii", params)
 					else:
 						params = False
-				elif repliedcomamnd in ("GetSelected3dlut", ):
+				elif repliedcommand in ("GetSelected3dlut", ):
 					if len(params) == 4:
 						params = struct.unpack("<i", params[0:4])[0]
 					else:
